@@ -47,10 +47,11 @@ static const QMap<QString, ShortcutV2::action> ActionMap = {
     {"TaskswitchSameAppPrev", ShortcutV2::action_taskswitch_sameapp_prev},
 };
 
-static const QMap<QString, ShortcutV2::keybind_mode> KeybindModeMap = {
-    {"KeyRelease", ShortcutV2::keybind_mode_key_release},
-    {"KeyPress", ShortcutV2::keybind_mode_key_press},
-    {"KeyPressRepeat", ShortcutV2::keybind_mode_key_press_repeat},
+static const QMap<QString, uint> KeybindModeMap = {
+    {"KeyPress", ShortcutV2::keybind_flag_key_press},
+    {"KeyRelease", ShortcutV2::keybind_flag_key_release},
+    {"KeyPressRepeat", ShortcutV2::keybind_flag_key_press | ShortcutV2::keybind_flag_repeat},
+    {"KeyReleaseRepeat", ShortcutV2::keybind_flag_key_release | ShortcutV2::keybind_flag_repeat},
 };
 
 static const QMap<QString, ShortcutV2::direction> GestureDirectionMap = {
@@ -288,12 +289,12 @@ void Shortcut::registerForManager(ShortcutV2 *manager)
     if (!shortcut.isEmpty()) {
         auto keybindName = QString("%1_key").arg(m_shortcutName);
 
-        ShortcutV2::keybind_mode mode = ShortcutV2::keybind_mode_key_press;
+        uint keybindFlags = ShortcutV2::keybind_flag_key_press;
         auto modeStr = m_settings.value("Shortcut/KeybindMode").toString();
         if (KeybindModeMap.contains(modeStr)) {
-            mode = KeybindModeMap.value(modeStr);
+            keybindFlags = KeybindModeMap.value(modeStr);
         }
-        manager->bind_key(keybindName, shortcut, mode, action);
+        manager->bind_key(keybindName, shortcut, keybindFlags, action);
         m_registeredBindings.append(keybindName);
     }
 
