@@ -203,15 +203,33 @@ public:
             const bool bufferChanged = committedState & WLR_SURFACE_STATE_BUFFER;
 
             if (bufferChanged) {
+                // Get the new buffer pointer from surface
+                auto newBuffer = surface->buffer();
+
                 if (!live) {
-                    pendingBuffer.reset(surface->buffer());
-                    if (Q_LIKELY(pendingBuffer))
-                        pendingBuffer->lock();
+                    // Non-live mode: update pendingBuffer
+                    // CRITICAL FIX: Only reset if the buffer pointer actually changed.
+                    // If pendingBuffer.get() == newBuffer (same pointer), calling reset() would:
+                    // 1. Call deleter (unlocker) on the old pointer → unlock()
+                    // 2. Set the new pointer (which is the same object)
+                    // 3. Then we call lock() again
+                    // This unlock-then-lock of the same buffer can cause n_locks to temporarily
+                    // hit 0, triggering wlroots' assert(buffer->n_locks > 0) in wlr_buffer_unlock().
+                    if (pendingBuffer.get() != newBuffer) {
+                        pendingBuffer.reset(newBuffer);
+                        if (Q_LIKELY(pendingBuffer))
+                            pendingBuffer->lock();
+                    }
                 } else {
-                    buffer.reset(surface->buffer());
-                    // lock buffer to ensure the WSurfaceItem can keep the last frame after WSurface destroyed.
-                    if (Q_LIKELY(buffer))
-                        buffer->lock();
+                    // Live mode: update buffer immediately
+                    // Same fix as above: only reset if the buffer pointer actually changed
+                    // to avoid double-unlock of the same buffer when surface commits without buffer change.
+                    if (buffer.get() != newBuffer) {
+                        buffer.reset(newBuffer);
+                        // lock buffer to ensure the WSurfaceItem can keep the last frame after WSurface destroyed.
+                        if (Q_LIKELY(buffer))
+                            buffer->lock();
+                    }
 
                     q->update();
                 }
@@ -588,7 +606,10 @@ void WSurfaceItemContent::releaseResources()
     d->invalidate();
 
     // Force to update the contents, avoid to render the invalid textures
-    QQuickItemPrivate::get(this)->dirty(QQuickItemPrivate::Content);
+    // Only mark dirty if we have a valid window to avoid crashes during window destruction
+    if (window()) {
+        QQuickItemPrivate::get(this)->dirty(QQuickItemPrivate::Content);
+    }
 }
 
 void WSurfaceItemContent::itemChange(ItemChange change, const ItemChangeData &data)
@@ -1128,8 +1149,8 @@ void WSurfaceItemPrivate::initForSurface()
     if (!surfaceState)
         surfaceState.reset(new SurfaceState());
 
-    QObject::connect(surface, &WWrapObject::aboutToBeInvalidated, q,
-                     &WSurfaceItem::releaseResources, Qt::DirectConnection);
+    surface->safeConnect(&WSurface::aboutToBeInvalidated, q,
+                         &WSurfaceItem::releaseResources, Qt::DirectConnection);
     surface->safeConnect(&WSurface::hasSubsurfaceChanged, q, [this]{ onHasSubsurfaceChanged(); });
     surface->safeConnect(&qw_surface::notify_commit, q, &WSurfaceItem::onSurfaceCommit);
 
@@ -1215,7 +1236,6 @@ void WSurfaceItemPrivate::onHasSubsurfaceChanged()
 
 void WSurfaceItemPrivate::updateSubsurfaceItem()
 {
-    Q_Q(WSurfaceItem);
     auto surface = this->surface->handle()->handle();
     Q_ASSERT(surface);
     Q_ASSERT(contentContainer);
@@ -1246,8 +1266,6 @@ void WSurfaceItemPrivate::updateSubsurfaceItem()
 
 void WSurfaceItemPrivate::onPaddingsChanged()
 {
-    W_Q(WSurfaceItem);
-
     if (!surface || !surfaceState)
         return;
 
